@@ -15,7 +15,7 @@ Usage::
 import sys
 from typing import Any, Dict, List, Type, overload
 
-from botocore.client import ClientMeta
+from botocore.client import BaseClient, ClientMeta
 
 from .literals import (
     AutoRenewType,
@@ -78,21 +78,26 @@ class Exceptions:
     ResourceNotFoundException: Type[BotocoreClientError]
 
 
-class ShieldClient:
+class ShieldClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/shield.html#Shield.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/shield.html#Shield.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html)
     """
 
     meta: ClientMeta
-    exceptions: Exceptions
+
+    @property
+    def exceptions(self) -> Exceptions:
+        """
+        ShieldClient exceptions.
+        """
 
     def associate_drt_log_bucket(self, *, LogBucket: str) -> Dict[str, Any]:
         """
         Authorizes the DDoS Response Team (DRT) to access the specified Amazon S3 bucket
         containing your AWS WAF logs.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/shield.html#Shield.Client.associate_drt_log_bucket)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/shield.html#Shield.Client.associate_drt_log_bucket)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#associate_drt_log_bucket)
         """
 
@@ -101,7 +106,7 @@ class ShieldClient:
         Authorizes the DDoS Response Team (DRT), using the specified role, to access
         your AWS account to assist with DDoS attack mitigation during potential attacks.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/shield.html#Shield.Client.associate_drt_role)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/shield.html#Shield.Client.associate_drt_role)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#associate_drt_role)
         """
 
@@ -109,7 +114,7 @@ class ShieldClient:
         """
         Adds health-based detection to the Shield Advanced protection for a resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/shield.html#Shield.Client.associate_health_check)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/shield.html#Shield.Client.associate_health_check)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#associate_health_check)
         """
 
@@ -120,7 +125,7 @@ class ShieldClient:
         Initializes proactive engagement and sets the list of contacts for the DDoS
         Response Team (DRT) to use.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/shield.html#Shield.Client.associate_proactive_engagement_details)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/shield.html#Shield.Client.associate_proactive_engagement_details)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#associate_proactive_engagement_details)
         """
 
@@ -128,7 +133,7 @@ class ShieldClient:
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/shield.html#Shield.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/shield.html#Shield.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#can_paginate)
         """
 
@@ -138,7 +143,7 @@ class ShieldClient:
         """
         Enables AWS Shield Advanced for a specific AWS resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/shield.html#Shield.Client.create_protection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/shield.html#Shield.Client.create_protection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#create_protection)
         """
 
@@ -156,7 +161,7 @@ class ShieldClient:
         Creates a grouping of protected resources so they can be handled as a
         collective.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/shield.html#Shield.Client.create_protection_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/shield.html#Shield.Client.create_protection_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#create_protection_group)
         """
 
@@ -164,7 +169,7 @@ class ShieldClient:
         """
         Activates AWS Shield Advanced for an account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/shield.html#Shield.Client.create_subscription)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/shield.html#Shield.Client.create_subscription)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#create_subscription)
         """
 
@@ -172,7 +177,7 @@ class ShieldClient:
         """
         Deletes an AWS Shield Advanced  Protection .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/shield.html#Shield.Client.delete_protection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/shield.html#Shield.Client.delete_protection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#delete_protection)
         """
 
@@ -180,7 +185,7 @@ class ShieldClient:
         """
         Removes the specified protection group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/shield.html#Shield.Client.delete_protection_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/shield.html#Shield.Client.delete_protection_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#delete_protection_group)
         """
 
@@ -188,7 +193,7 @@ class ShieldClient:
         """
         Removes AWS Shield Advanced from an account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/shield.html#Shield.Client.delete_subscription)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/shield.html#Shield.Client.delete_subscription)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#delete_subscription)
         """
 
@@ -196,7 +201,7 @@ class ShieldClient:
         """
         Describes the details of a DDoS attack.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/shield.html#Shield.Client.describe_attack)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/shield.html#Shield.Client.describe_attack)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#describe_attack)
         """
 
@@ -206,7 +211,7 @@ class ShieldClient:
         detected in the last year for all resources that belong to your account,
         regardless of whether you've defined Shield protections for them.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/shield.html#Shield.Client.describe_attack_statistics)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/shield.html#Shield.Client.describe_attack_statistics)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#describe_attack_statistics)
         """
 
@@ -216,7 +221,7 @@ class ShieldClient:
         Response Team (DRT) to access your AWS account while assisting with attack
         mitigation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/shield.html#Shield.Client.describe_drt_access)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/shield.html#Shield.Client.describe_drt_access)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#describe_drt_access)
         """
 
@@ -228,7 +233,7 @@ class ShieldClient:
         can use to contact you if you have proactive engagement enabled, for escalations
         to the DRT and to initiate proactive customer support.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/shield.html#Shield.Client.describe_emergency_contact_settings)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/shield.html#Shield.Client.describe_emergency_contact_settings)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#describe_emergency_contact_settings)
         """
 
@@ -238,7 +243,7 @@ class ShieldClient:
         """
         Lists the details of a  Protection object.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/shield.html#Shield.Client.describe_protection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/shield.html#Shield.Client.describe_protection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#describe_protection)
         """
 
@@ -248,7 +253,7 @@ class ShieldClient:
         """
         Returns the specification for the specified protection group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/shield.html#Shield.Client.describe_protection_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/shield.html#Shield.Client.describe_protection_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#describe_protection_group)
         """
 
@@ -256,7 +261,7 @@ class ShieldClient:
         """
         Provides details about the AWS Shield Advanced subscription for an account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/shield.html#Shield.Client.describe_subscription)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/shield.html#Shield.Client.describe_subscription)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#describe_subscription)
         """
 
@@ -265,7 +270,7 @@ class ShieldClient:
         Removes authorization from the DDoS Response Team (DRT) to notify contacts about
         escalations to the DRT and to initiate proactive customer support.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/shield.html#Shield.Client.disable_proactive_engagement)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/shield.html#Shield.Client.disable_proactive_engagement)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#disable_proactive_engagement)
         """
 
@@ -274,7 +279,7 @@ class ShieldClient:
         Removes the DDoS Response Team's (DRT) access to the specified Amazon S3 bucket
         containing your AWS WAF logs.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/shield.html#Shield.Client.disassociate_drt_log_bucket)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/shield.html#Shield.Client.disassociate_drt_log_bucket)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#disassociate_drt_log_bucket)
         """
 
@@ -282,7 +287,7 @@ class ShieldClient:
         """
         Removes the DDoS Response Team's (DRT) access to your AWS account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/shield.html#Shield.Client.disassociate_drt_role)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/shield.html#Shield.Client.disassociate_drt_role)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#disassociate_drt_role)
         """
 
@@ -293,7 +298,7 @@ class ShieldClient:
         Removes health-based detection from the Shield Advanced protection for a
         resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/shield.html#Shield.Client.disassociate_health_check)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/shield.html#Shield.Client.disassociate_health_check)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#disassociate_health_check)
         """
 
@@ -303,7 +308,7 @@ class ShieldClient:
         contacts about escalations to the DRT and to initiate proactive customer
         support.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/shield.html#Shield.Client.enable_proactive_engagement)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/shield.html#Shield.Client.enable_proactive_engagement)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#enable_proactive_engagement)
         """
 
@@ -317,7 +322,7 @@ class ShieldClient:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/shield.html#Shield.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/shield.html#Shield.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#generate_presigned_url)
         """
 
@@ -325,7 +330,7 @@ class ShieldClient:
         """
         Returns the `SubscriptionState` , either `Active` or `Inactive` .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/shield.html#Shield.Client.get_subscription_state)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/shield.html#Shield.Client.get_subscription_state)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#get_subscription_state)
         """
 
@@ -342,7 +347,7 @@ class ShieldClient:
         Returns all ongoing DDoS attacks or all DDoS attacks during a specified time
         period.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/shield.html#Shield.Client.list_attacks)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/shield.html#Shield.Client.list_attacks)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#list_attacks)
         """
 
@@ -352,7 +357,7 @@ class ShieldClient:
         """
         Retrieves the  ProtectionGroup objects for the account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/shield.html#Shield.Client.list_protection_groups)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/shield.html#Shield.Client.list_protection_groups)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#list_protection_groups)
         """
 
@@ -362,7 +367,7 @@ class ShieldClient:
         """
         Lists all  Protection objects for the account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/shield.html#Shield.Client.list_protections)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/shield.html#Shield.Client.list_protections)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#list_protections)
         """
 
@@ -372,7 +377,7 @@ class ShieldClient:
         """
         Retrieves the resources that are included in the protection group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/shield.html#Shield.Client.list_resources_in_protection_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/shield.html#Shield.Client.list_resources_in_protection_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#list_resources_in_protection_group)
         """
 
@@ -381,7 +386,7 @@ class ShieldClient:
         Gets information about AWS tags for a specified Amazon Resource Name (ARN) in
         AWS Shield.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/shield.html#Shield.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/shield.html#Shield.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#list_tags_for_resource)
         """
 
@@ -389,7 +394,7 @@ class ShieldClient:
         """
         Adds or updates tags for a resource in AWS Shield.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/shield.html#Shield.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/shield.html#Shield.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#tag_resource)
         """
 
@@ -397,7 +402,7 @@ class ShieldClient:
         """
         Removes tags from a resource in AWS Shield.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/shield.html#Shield.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/shield.html#Shield.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#untag_resource)
         """
 
@@ -409,7 +414,7 @@ class ShieldClient:
         DDoS Response Team (DRT) can use to contact you if you have proactive engagement
         enabled, for escalations to the DRT and to initiate proactive customer support.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/shield.html#Shield.Client.update_emergency_contact_settings)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/shield.html#Shield.Client.update_emergency_contact_settings)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#update_emergency_contact_settings)
         """
 
@@ -425,7 +430,7 @@ class ShieldClient:
         """
         Updates an existing protection group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/shield.html#Shield.Client.update_protection_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/shield.html#Shield.Client.update_protection_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#update_protection_group)
         """
 
@@ -433,14 +438,14 @@ class ShieldClient:
         """
         Updates the details of an existing subscription.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/shield.html#Shield.Client.update_subscription)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/shield.html#Shield.Client.update_subscription)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#update_subscription)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_attacks"]) -> ListAttacksPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/shield.html#Shield.Paginator.ListAttacks)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/shield.html#Shield.Paginator.ListAttacks)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/paginators.html#listattackspaginator)
         """
 
@@ -449,6 +454,6 @@ class ShieldClient:
         self, operation_name: Literal["list_protections"]
     ) -> ListProtectionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/shield.html#Shield.Paginator.ListProtections)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/shield.html#Shield.Paginator.ListProtections)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/paginators.html#listprotectionspaginator)
         """
